Learn R Programming

congressbr (version 0.2.2)

cham_bill_info_id: Downloads details of a specific bill by providing id of a bill

Description

Downloads details of a specific bill by providing id of a bill

Usage

cham_bill_info_id(bill_id, ascii = T)

Arguments

bill_id

integer. The id number of the bill.

ascii

logical. If TRUE, certain strings are converted to ascii format.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
cham_bill_info_id(14784)
# }

Run the code above in your browser using DataLab