Learn R Programming

congressbr (version 0.2.2)

cham_plenary_bills: This function lists every bill voted on in plenary.

Description

This function lists every bill voted on in plenary.

Usage

cham_plenary_bills(year, type = "", ascii = T)

Arguments

year

(integer) start year of the period requested.

type

character. The type of the bill. For example, "PL"

ascii

logical. If TRUE, certain strings are converted to ascii format.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
cham_plenary_bills(year = 2008)
# }

Run the code above in your browser using DataLab