Learn R Programming

congressbr (version 0.2.2)

sen_bill_sponsors: Downloads and tidies data on the bill sponsors in the Federal Senate

Description

Downloads and tidies data on the bill sponsors in the Federal Senate.

Usage

sen_bill_sponsors(ascii = TRUE)

Arguments

ascii

(logical). If TRUE, bill sponsor names are converted to ascii format, stripping the latin characters from the names.

Value

A tibble, of classes tbl_df, tbl and data.frame, with variables:

  • sponsor_name: identity of the bill sponsor.

  • sponsor_code: code for senator bill sponsors.

  • sponsor_title: title of bill sponsor.

  • sponsor_party: party of bill sponsor.

  • sponsor_state: state of bill sponsor.

  • quantity: quantity of bills sponsored by this individual or entity.

Examples

Run this code
# NOT RUN {
bills <- sen_bill_sponsors()
# }

Run the code above in your browser using DataLab