Learn R Programming

congressbr (version 0.2.2)

sen_bills_limits: Downloads and tidies information on the types of deadline and time limits for legislation in the Federal Senate

Description

Downloads and tidies information on the types of deadline and time limits for legislation in the Federal Senate.

Usage

sen_bills_limits(ascii = TRUE)

Arguments

ascii

logical. If TRUE, strips Latin characters from strings.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
lims <- sen_bills_limits()
# }

Run the code above in your browser using DataLab