Learn R Programming

congressbr (version 0.2.2)

sen_bills_list: Downloads and tidies information on the types of acts that can be formally made in the Federal Senate

Description

Downloads and tidies information on the types of acts that can be formally made in the Federal Senate.

Usage

sen_bills_list(active = NULL, ascii = TRUE)

Arguments

active

.Possible values are TRUE, FALSE, or can be left as NULL, in which case both active and inactive bill types are returned.

ascii

logical. TRUE by default, removes latin-1 characters from returned object.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
bills <- sen_bills_list(active = TRUE)
# }

Run the code above in your browser using DataLab