Learn R Programming

congressbr (version 0.2.2)

sen_bills_passing: Downloads and tidies information on legislation that is under consideration in the Federal Senate

Description

Downloads and tidies information on legislation that is under consideration in the Federal Senate.

Usage

sen_bills_passing(
  year = NULL,
  number = NULL,
  type = NULL,
  date = NULL,
  time = NULL
)

Arguments

year

Format YYYY. Returns legislation from this year.

number

bill number.

type

type of legislation.

date

date requested, format YYYYMMDD. Returns information on legislation on or after this time.

time

Format hour-minute-second (HHmmSS). Returns information on legislation on or after this time.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
sen_bills_passing()
# All MPVs (provisional presidential decrees) in 2001:
mpvs <- sen_bills_passing(year = "2001", type = "MPV")
# Bills from a certain date:
march01_2017 <- sen_bills_passing(date = 20170301)
# }

Run the code above in your browser using DataLab