Learn R Programming

congressbr (version 0.2.2)

sen_bills_situations: Downloads and tidies information on the possible situations a bill can be in

Description

Downloads and tidies information on the possible situations a bill can be in.

Usage

sen_bills_situations(ascii = TRUE)

Arguments

ascii

logical. If TRUE, strips Latin characters from strings.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
sen_bills_situations()
# }

Run the code above in your browser using DataLab