Learn R Programming

congressbr (version 0.2.2)

sen_bills_status: Downloads and tidies information on legislation from the current legislature of the Federal Senate

Description

Downloads and tidies information on legislation from the current legislature of the Federal Senate.

Usage

sen_bills_status(bill_id = NULL, ascii = TRUE)

Arguments

bill_id

integer. This number is the id given to each bill in the Senate database. For example, running sen_bills_current() will return a dataframe with the variable bill_id in the first column. These numbers can be used as this id.

ascii

logical. If TRUE, strips Latin characters from strings.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
sen_bills_status(bill_id = 80406)
# }

Run the code above in your browser using DataLab