Learn R Programming

congressbr (version 0.2.2)

sen_bills_topics: Downloads and tidies information on the topics of legislation in the Federal Senate

Description

Downloads and tidies information on the topics of legislation in the Federal Senate.

Usage

sen_bills_topics(active = NULL, ascii = TRUE)

Arguments

active

character. Options are "Yes", "No" or NULL, the default. "Yes" returns active subtypes, "No" returns inactive subtypes, while the default returns both.

ascii

logical. If TRUE, strips Latin characters from strings.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
top <- sen_bills_topics()
# }

Run the code above in your browser using DataLab