Learn R Programming

congressbr (version 0.2.2)

sen_budget: Downloads and tidies budget information from the Federal Senate

Description

Downloads and tidies budget information from the Federal Senate.

Usage

sen_budget(ascii = TRUE)

Arguments

ascii

logical. If TRUE, certain strings are converted to ascii format.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
bud <- sen_budget()
# }

Run the code above in your browser using DataLab