Learn R Programming

congressbr (version 0.2.2)

sen_coalitions: Downloads and tidies data on the coalitions in the Federal Senate

Description

Downloads and tidies data on the coalitions in the Federal Senate.

Usage

sen_coalitions(ascii = TRUE)

Arguments

ascii

logical. If TRUE, names are converted to ascii format.

Value

A tibble, of classes tbl_df, tbl and data.frame, with variables:

  • bloc_code: unique code given to each coalition.

  • bloc_name: name of the coalition.

  • bloc_label: additional label for the coalition.

  • date_created: POSIXct, date the coalition was created.

Examples

Run this code
# NOT RUN {
coalitions <- sen_coalitions()
# }

Run the code above in your browser using DataLab