Learn R Programming

congressbr (version 0.2.2)

sen_commission_positions: Information on positions (jobs) that legislators may occupy in commissions in the Federal Senate

Description

Information on positions (jobs) that legislators may occupy in commissions in the Federal Senate.

Usage

sen_commission_positions(active = c("Both", "Yes", "No"), ascii = TRUE)

Arguments

active

character. If "No", returns all positions, otherwise returns positions that are presently active.

ascii

logical. If TRUE, certain strings are converted to ascii format.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Details

Returns a data frame with the following variables:

  • comm_position_id: unique code for each position.

  • comm_position: name of the position.

  • comm_position_active: whether the position is currently active or not.

Examples

Run this code
# NOT RUN {
jobs <- sen_commission_positions(active = "No")
# }

Run the code above in your browser using DataLab