Learn R Programming

congressbr (version 0.2.2)

sen_parties: Downloads and tidies information on the political parties in the Federal Senate

Description

Downloads and tidies information on the political parties in the Federal Senate.

Usage

sen_parties(ascii = TRUE)

Arguments

ascii

logical. TRUE by default, removes latin-1 characters from returned object.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
party <- sen_parties()
# }

Run the code above in your browser using DataLab