Learn R Programming

congressbr (version 0.2.2)

sen_plenary_agenda: Returns results from the plenary in the Federal Senate for a specified date

Description

Returns results from the plenary in the Federal Senate for a specified date.

Usage

sen_plenary_agenda(period = c("month", "day"), date = NULL, ascii = TRUE)

Arguments

period

character. If "month" is selected, all information available from the date specified with date to the end of the month is returned. Otherwise, information returned from the day of date only is returned.

date

character. Format YYYYMMDD.

ascii

logical. If TRUE, the default, strips Latin characters from the results.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
# get info from the second half of March 2014:
sessions <- sen_plenary_agenda(period = "month", date = "20140315")
# or from the first of April 2016:
sessions <- sen_plenary_agenda(period = "day", date = "20160401")
# }

Run the code above in your browser using DataLab