Learn R Programming

congressbr (version 0.2.2)

sen_plenary_leaderships: Returns information on leaderships in the Federal Senate

Description

Returns information on leaderships in the Federal Senate.

Usage

sen_plenary_leaderships(parties = TRUE, ascii = TRUE)

Arguments

parties

logical. Returns information on party leadership in the Senate when TRUE, otherwise returns information on coalitions.

ascii

logical. If TRUE, the default, strips Latin characters from the results.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
party_leaders <- sen_plenary_leaderships()
# }

Run the code above in your browser using DataLab