Learn R Programming

congressbr (version 0.2.2)

sen_plenary_sessions: Returns the types of sessions in the Federal Senate

Description

Returns the types of sessions in the Federal Senate.

Usage

sen_plenary_sessions(active = c("Yes", "No"), ascii = TRUE)

Arguments

active

. Default "Yes", which returns session types which are still used. Otherwise, returns all types of sessions.

ascii

logical. If TRUE, the default, strips Latin characters from the results.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
sessions <- sen_plenary_sessions()
# }

Run the code above in your browser using DataLab