Downloads and tidies information on bills that certain senators have sponsored/authored in the Federal Senate.
sen_senator_bills(id = 0, ascii = TRUE)integer. This number represents the id of the senator
you wish to get information on. These ids can be extracted from the API
using the sen_senator_list() function, where they will appear as the
first column in the data frame returned, under the name 'id'.
logical. If TRUE, certain strings are converted to ascii
format.
A tibble, of classes tbl_df, tbl and data.frame.
sen_senator_list()