Learn R Programming

congressbr (version 0.2.2)

sen_senator_list: Downloads and tidies information on the senators in the Federal Senate

Description

Downloads and tidies information on the senators in the Federal Senate.

Usage

sen_senator_list(present = TRUE, state = NULL, status = NULL, ascii = TRUE)

Arguments

present

logical. If TRUE, downloads data on the legislature currently sitting in the Federal Senate, otherwise returns information on senators who are currently absent.

state

character. Two-letter abbreviation of Brazilian state. A list of these is available with the function UF().

status

character, either "T" or "S", representing titular or suplente (stand-in senator), respectively.

ascii

logical. If TRUE, strips Latin characters from strings.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
all <- sen_senator_list()
# }
# NOT RUN {
# Who represents Rio de Janeiro?
# }
# NOT RUN {
rj <- sen_senator_list(state = "RJ")
# }

Run the code above in your browser using DataLab