Learn R Programming

congressbr (version 0.2.2)

sen_votes_year: Returns voting information from the Senate floor for the year requested using standard method

Description

Returns voting information from the Senate floor for the year requested.

Usage

sen_votes_year(year, ascii = T, binary = T)

Arguments

year

character or integer. Format YYYY

ascii

logical. If TRUE, the default, strips Latin characters from the results.

binary

logical. If TRUE, the default, transforms votes into 1 for "yes", 0, for "no" and NA for everything else. If FALSE, returns a character vector of vote decisions.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
sen_votes_year("2013")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab