Learn R Programming

congressbr (version 0.2.2)

sen_votes_year_file: Returns voting information from the Senate floor for the year requested using xml file method

Description

Returns voting information from the Senate floor for the year requested (Only available from 1991 through 2017).

Usage

sen_votes_year_file(year = NULL, binary = TRUE, ascii = TRUE)

Arguments

year

character or integer. Format YYYY

binary

logical. If TRUE, the default, transforms votes into 1 for "yes", 0, for "no" and NA for everything else. If FALSE, returns a character vector of vote decisions.

ascii

logical. If TRUE, the default, strips Latin characters from the results.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
sen_votes_year_file("2013")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab