Search for data on legislation in the Brazilian Federal Senate.
sen_bill_search(
year = "",
year_law = "",
topic_id = "",
situation_id = "",
date_presented_init = "",
date_presented_end = "",
date_situation_init = "",
date_situation_end = "",
complementary = "",
present = "",
rapporteur = "",
author = "",
number = "",
type = "",
law_number = "",
party_abbr_author = "",
author_state = "",
in_passage = "",
ascii = TRUE
)integer. Four-digit year, such as 2013.
integer. Year of introduction of the law, such as 2013.
character. For a data frame of topic ids and their meanings,
use sen_bills_topics().
character.
character. Date when the bill that you're
searching for was first presented. In the format YYYYMMDD.
character. See above.
character. See above.
character. See above.
character. Either blank, "Yes", or "No".
character. Either blank, "Yes", or "No"; an indicator for
whether the bill is current or not.
character. Name of the rapporteur of the bill, if known.
character. Author/sponsor of the bill. For a list,
use sen_bill_sponsors().
character. Bill number, if known.
character. Bill type. For a data frame of possible bill
types, run sen_bills_types().
character. Number of the law resulting from the bill,
if known.
character. The short text code for the party
of the author of the bill. For a list of the parties, use sen_parties().
character. The state of the senator. For a
full list, see UF().
character. Either blank, "Yes", or "No".
logical. If TRUE, certain strings are converted to ascii
format.
A tibble, of classes tbl_df, tbl and data.frame.
# NOT RUN {
# search for legislation from 2014:
# }
# NOT RUN {
two14 <- sen_bill_search(year = 2014)
# }
Run the code above in your browser using DataLab