powered by
Downloads and tidies data on the bill sponsors in the Federal Senate.
sen_bill_sponsors(ascii = TRUE)
(logical). If TRUE, bill sponsor names are converted to ascii format, stripping the latin characters from the names.
logical
A tibble, of classes tbl_df, tbl and data.frame, with variables:
tbl_df
tbl
data.frame
sponsor_name: identity of the bill sponsor.
sponsor_name:
sponsor_code: code for senator bill sponsors.
sponsor_code:
sponsor_title: title of bill sponsor.
sponsor_title:
sponsor_party: party of bill sponsor.
sponsor_party:
sponsor_state: state of bill sponsor.
sponsor_state:
quantity: quantity of bills sponsored by this individual or entity.
quantity:
# NOT RUN { bills <- sen_bill_sponsors() # }
Run the code above in your browser using DataLab