powered by
Downloads and tidies information on the types of deadline and time limits for legislation in the Federal Senate.
sen_bills_limits(ascii = TRUE)
logical. If TRUE, strips Latin characters from strings.
logical
TRUE
A tibble, of classes tbl_df, tbl and data.frame.
tbl_df
tbl
data.frame
# NOT RUN { lims <- sen_bills_limits() # }
Run the code above in your browser using DataLab