powered by
Downloads and tidies information on the types of acts that can be formally made in the Federal Senate.
sen_bills_list(active = NULL, ascii = TRUE)
.Possible values are TRUE, FALSE, or can be left as NULL, in which case both active and inactive bill types are returned.
TRUE
FALSE
NULL
logical. TRUE by default, removes latin-1 characters from returned object.
logical
A tibble, of classes tbl_df, tbl and data.frame.
tbl_df
tbl
data.frame
# NOT RUN { bills <- sen_bills_list(active = TRUE) # }
Run the code above in your browser using DataLab