sen_bills_locations: Downloads and tidies information on the possible locations a piece
of legislation can currently be passing through the Federal Senate
Description
Downloads and tidies information on the possible locations a piece
of legislation can currently be passing through the Federal Senate.
Usage
sen_bills_locations(active = NULL, ascii = TRUE)
Arguments
active
character. Options are "Yes", "No" or NULL, the
default. "Yes" returns active subtypes, "No" returns inactive subtypes,
while the default returns both.
ascii
logical. If TRUE, strips Latin characters from
strings.