sen_bills_passage: Downloads and tidies information on the possible locations a piece
of legislation can currently be passing through
Description
Downloads and tidies information on the possible locations a piece
of legislation can currently be passing through.
Usage
sen_bills_passage(bill_id = NULL, ascii = TRUE)
Arguments
bill_id
integer. This number is the id given to each bill in the
Senate database. For example, running sen_bills_current() will return a
dataframe with the variable bill_id in the first column. These numbers
can be used as this id.
ascii
logical. If TRUE, strips Latin characters from
strings.