sen_bills_status: Downloads and tidies information on legislation from the current
legislature of the Federal Senate
Description
Downloads and tidies information on legislation from the current
legislature of the Federal Senate.
Usage
sen_bills_status(bill_id = NULL, ascii = TRUE)
Arguments
bill_id
integer. This number is the id given to each bill in the
Senate database. For example, running sen_bills_current() will return a
dataframe with the variable bill_id in the first column. These numbers
can be used as this id.
ascii
logical. If TRUE, strips Latin characters from
strings.