sen_bills_topics: Downloads and tidies information on the topics of legislation in
the Federal Senate
Description
Downloads and tidies information on the topics of legislation in
the Federal Senate.
Usage
sen_bills_topics(active = NULL, ascii = TRUE)
Arguments
active
character. Options are "Yes", "No" or NULL, the
default. "Yes" returns active subtypes, "No" returns inactive subtypes,
while the default returns both.
ascii
logical. If TRUE, strips Latin characters from
strings.