Downloads and tidies data on specific coalitions in the Federal Senate.
sen_coalition_info(code = NULL, ascii = TRUE)integer. Code of the coalition. If not known (the most likely
case), these codes can be obtained from the sen_coalitions() function.
logical. If TRUE, names are converted to ascii format.
A tibble, of classes tbl_df, tbl and data.frame,
with variables:
bloc_code: unique code given to each coalition.
house: legislative house for the coalition.
bloc_name: name of the coalition.
bloc_label: additional label for the coalition.
date_created: POSIXct, date the coalition was created.
member_code: party code.
member_date_joined: POSIXct, date when the party first joined the coalition.
member_abbr: party acronym.
member_name: party name.
member_date_created:: POSIXct, date when the coalition was created.