powered by
Returns information on leaderships in the Federal Senate.
sen_plenary_leaderships(parties = TRUE, ascii = TRUE)
logical. Returns information on party leadership in the Senate when TRUE, otherwise returns information on coalitions.
logical
TRUE
logical. If TRUE, the default, strips Latin characters from the results.
A tibble, of classes tbl_df, tbl and data.frame.
tbl_df
tbl
data.frame
# NOT RUN { party_leaders <- sen_plenary_leaderships() # }
Run the code above in your browser using DataLab