Learn R Programming

congressbr (version 0.2.2)

sen_plenary_result: Returns results from the plenary in the Federal Senate for a specified date

Description

Returns results from the plenary in the Federal Senate for a specified date.

Usage

sen_plenary_result(date = NULL, ascii = TRUE)

Arguments

date

character. Format YYYYMMDD.

ascii

logical. If TRUE, the default, strips Latin characters from the results.

Value

A tibble, of classes tbl_df, tbl and data.frame.

Examples

Run this code
# NOT RUN {
# get info for the 3rd of March 2016:
x <- sen_plenary_result(date = "20160303")
# Earlier periods may not have information:
# }
# NOT RUN {
sen_plenary_result(date = "20110405")
# }

Run the code above in your browser using DataLab