powered by
Returns results from the plenary in the Federal Senate for a specified date.
sen_plenary_result(date = NULL, ascii = TRUE)
character. Format YYYYMMDD.
character
logical. If TRUE, the default, strips Latin characters from the results.
logical
TRUE
A tibble, of classes tbl_df, tbl and data.frame.
tbl_df
tbl
data.frame
# NOT RUN { # get info for the 3rd of March 2016: x <- sen_plenary_result(date = "20160303") # Earlier periods may not have information: # } # NOT RUN { sen_plenary_result(date = "20110405") # }
Run the code above in your browser using DataLab