powered by
Returns the types of sessions in the Federal Senate.
sen_plenary_sessions(active = c("Yes", "No"), ascii = TRUE)
. Default "Yes", which returns session types which are still used. Otherwise, returns all types of sessions.
logical. If TRUE, the default, strips Latin characters from the results.
logical
TRUE
A tibble, of classes tbl_df, tbl and data.frame.
tbl_df
tbl
data.frame
# NOT RUN { sessions <- sen_plenary_sessions() # }
Run the code above in your browser using DataLab