Learn R Programming

congressbr (version 0.2.2)

sen_senator_commissions: Downloads and tidies information on the commissions on which senators have served or are serving in the Federal Senate

Description

Downloads and tidies information on the commissions on which senators have served or are serving in the Federal Senate.

Usage

sen_senator_commissions(id = 0, ascii = TRUE)

Arguments

id

integer. This number represents the id of the senator you wish to get information on. These ids can be extracted from the API using the sen_senator_list() function, where they will appear as the first column in the data frame returned, under the name 'id'.

ascii

logical. If TRUE, certain strings are converted to ascii format.

Value

A tibble, of classes tbl_df, tbl and data.frame.

See Also

sen_senator_list()