sen_senator_legis: Downloads and tidies information on the senators in the Federal Senate
Description
Downloads and tidies information on the senators in the Federal Senate.
Usage
sen_senator_legis(
start = NULL,
end = NULL,
state = NULL,
status = NULL,
ascii = TRUE
)
Arguments
start
two-digit integer representing the first legislature of the
time period requested.
end
two-digit integer representing the final legislature of the time
period requested.
state
character. Two-letter abbreviation of Brazilian state. A list of these is
available with the function UF().
status
character, either "T" or "S", representing
titular or suplente (stand-in senator), respectively.
ascii
logical. If TRUE, strips Latin characters from
strings.
Value
A tibble, of classes tbl_df, tbl and data.frame.
Examples
Run this code# NOT RUN {
all <- sen_senator_legis(start = 50)
# }
Run the code above in your browser using DataLab