sen_senator_suplentes: Downloads and tidies information on titular senators and their
suplentes in the Federal Senate
Description
Downloads and tidies information on titular senators and their
suplentes in the Federal Senate.
Usage
sen_senator_suplentes(id = 0, ascii = TRUE)
Arguments
id
integer. This number represents the id of the senator
you wish to get information on. These ids can be extracted from the API
using the sen_senator_list() function, where they will appear as the
first column in the data frame returned, under the name 'id'.
ascii
logical. If TRUE, certain strings are converted to ascii
format.
# NOT RUN {# A titular senator, Jos<U+00E9> Serra:Serra <- sen_senator_suplentes(id = 90)
# Or one of his suplentes:suplente <- sen_senator_suplentes(id = 878)
# }