sen_votes_year: Returns voting information from the Senate floor for the year
requested using standard method
Description
Returns voting information from the Senate floor for the year
requested.
Usage
sen_votes_year(year, ascii = T, binary = T)
Arguments
year
character or integer. Format YYYY
ascii
logical. If TRUE, the default, strips Latin
characters from the results.
binary
logical. If TRUE, the default, transforms
votes into 1 for "yes", 0, for "no" and NA for everything
else. If FALSE, returns a character vector of vote decisions.