powered by
Returns voting information from the Senate floor for the year requested (Only available from 1991 through 2017).
sen_votes_year_file(year = NULL, binary = TRUE, ascii = TRUE)
character or integer. Format YYYY
character
integer
logical. If TRUE, the default, transforms votes into 1 for "yes", 0, for "no" and NA for everything else. If FALSE, returns a character vector of vote decisions.
logical
TRUE
1
0
NA
FALSE
logical. If TRUE, the default, strips Latin characters from the results.
A tibble, of classes tbl_df, tbl and data.frame.
tbl_df
tbl
data.frame
# NOT RUN { sen_votes_year_file("2013") # } # NOT RUN { # }
Run the code above in your browser using DataLab